@@ -21,9 +21,9 @@ import (
 
 	addonv1alpha1 "github.com/open-cluster-management/api/addon/v1alpha1"
 	workv1 "github.com/open-cluster-management/api/work/v1"
-	placementv1 "github.com/open-cluster-management/multicloud-operators-placementrule/pkg/apis/apps/v1"
-	"github.com/open-cluster-management/multicluster-monitoring-operator/pkg/apis"
-	"github.com/open-cluster-management/multicluster-monitoring-operator/pkg/config"
+	placementv1 "github.com/stolostron/multicloud-operators-placementrule/pkg/apis/apps/v1"
+	"github.com/stolostron/multicluster-monitoring-operator/pkg/apis"
+	"github.com/stolostron/multicluster-monitoring-operator/pkg/config"
 )
 
 const (
