@@ -5,7 +5,7 @@ package util
 import (
 	"context"
 
-	addonv1alpha1 "github.com/open-cluster-management/addon-framework/api/v1alpha1"
+	addonv1alpha1 "github.com/open-cluster-management/api/addon/v1alpha1"
 	"k8s.io/apimachinery/pkg/api/errors"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/apimachinery/pkg/types"
@@ -37,16 +37,30 @@ func CreateManagedClusterAddonCR(client client.Client, namespace string) error {
 				Name:      ManagedClusterAddonName,
 				Namespace: namespace,
 			},
+			Status: addonv1alpha1.ManagedClusterAddOnStatus{
+				AddOnConfiguration: addonv1alpha1.ConfigCoordinates{
+					CRDName: "observabilityaddons.observability.open-cluster-management.io",
+					CRName:  "observability-addon",
+				},
+				AddOnMeta: addonv1alpha1.AddOnMeta{
+					DisplayName: "Observability Controller",
+					Description: "Manages Observability components.",
+				},
+			},
 		}
-
 		if err := client.Create(context.TODO(), newManagedClusterAddon); err != nil {
 			log.Error(err, "Cannot create observability-controller  ManagedClusterAddOn")
 			return err
 		}
+		if err := client.Status().Update(context.TODO(), newManagedClusterAddon); err != nil {
+			log.Error(err, "Cannot update status for observability-controller  ManagedClusterAddOn")
+			return err
+		}
 	} else if err != nil {
 		log.Error(err, "Failed to get ManagedClusterAddOn ", "namespace", namespace)
 		return err
 	}
 	log.Info("ManagedClusterAddOn already present", "namespace", namespace)
+
 	return nil
 }
